unit GameViewMain;

interface

uses Classes,
  CastleVectors, CastleComponentSerialize,
  CastleUIControls, CastleControls, CastleKeysMouse,
  Figures;

type
  TMainMenuDesign = class(TCastleDesign)
  private
    FCloseButton,
    FCubesButton,
    FSpheresButton : TCastleButton;
  public
    property ExitButton : TCastleButton read FCloseButton write FCloseButton;
    property CubesButton : TCastleButton read FCubesButton write FCubesButton;
    property SpheresButton : TCastleButton read FSpheresButton write FSpheresButton;

    constructor Create(AOwner: TComponent); override;

    procedure ExitGame(Sender : TObject);
    procedure OpenCubesViewport(Sender : TObject);
    procedure OpenSpheresViewport(Sender : TObject);
	end;

  TViewMain = class(TCastleView)
  published
    LabelFps: TCastleLabel;

    MainMenu : TMainMenuDesign;

    SpheresViewport,
    CubesViewport : TCastleDesign;
  public
    constructor Create(AOwner: TComponent); override;
    procedure Start; override;
    procedure Update(const SecondsPassed: Single; var HandleInput: Boolean); override;
    function Press(const Event: TInputPressRelease): Boolean; override;

                                             
    procedure CloseGame;
    procedure ToMainMenu;
    procedure ToCubesViewport;
    procedure ToSpheresViewport;
  end;

var
  ViewMain: TViewMain;

implementation

uses
  SysUtils,
  CastleWindow;

{ TMainMenuDesign------------------------------------------------------------- }

constructor TMainMenuDesign.Create(AOwner: TComponent);
begin
  inherited;
  Url := 'castle-data:/menudesign.castle-user-interface';
  Anchor(hpMiddle);
  Anchor(vpMiddle);
  FullSize := True;

  SpheresButton := DesignedComponent('Button1') as TCastleButton;
  SpheresButton.OnClick := @OpenSpheresViewport;
  CubesButton := DesignedComponent('Button2') as TCastleButton; 
  CubesButton.OnClick := @OpenCubesViewport;
  ExitButton := DesignedComponent('Button3') as TCastleButton;
  ExitButton.OnClick := @ExitGame;
end;

procedure TMainMenuDesign.OpenCubesViewport(Sender : TObject);
begin
  ViewMain.ToCubesViewport;
  Exists := False;
end;

procedure TMainMenuDesign.OpenSpheresViewport(Sender : TObject);
begin
  ViewMain.ToSpheresViewport;
  Exists := False;
end;              

procedure TMainMenuDesign.ExitGame(Sender : TObject);
begin
  ViewMain.CloseGame;
end;
                   
{ TViewMain ------------------------------------------------------------------ }

constructor TViewMain.Create(AOwner: TComponent);
begin
  inherited;
  DesignUrl := 'castle-data:/gameviewmain.castle-user-interface';
end;

procedure TViewMain.Start;
begin
  inherited;

  SpheresViewport := TSpheresView.Create(Self);
  InsertFront(SpheresViewport);
  CubesViewport := TCubesView.Create(Self);  
  InsertFront(CubesViewport);
  MainMenu := TMainMenuDesign.Create(Self); 
  InsertFront(MainMenu);
end;

procedure TViewMain.Update(const SecondsPassed: Single; var HandleInput: Boolean);
begin
  inherited;
  Assert(LabelFps <> nil, 'If you remove LabelFps from the design, remember to remove also the assignment "LabelFps.Caption := ..." from code');
  LabelFps.Caption := 'FPS: ' + Container.Fps.ToString;
end;

function TViewMain.Press(const Event: TInputPressRelease): Boolean;
begin
  Result := inherited;
  if Result then Exit;
end;
                 
procedure TViewMain.CloseGame;
begin       
  Application.Terminate;
end;

procedure TViewMain.ToMainMenu;
begin
  MainMenu.Exists := True;
end;

procedure TViewMain.ToCubesViewport;
begin
  CubesViewport.Exists := True;
end;

procedure TViewMain.ToSpheresViewport;
begin
  SpheresViewport.Exists := True;
end;

end.
